==> 0.0.2.tar.gz: lib/app/modules/app/controllers/app_controller.dart <==
import 'package:get/get.dart';
import 'package:pedantic/pedantic.dart';
import 'dart:typed_data';

import 'package:camera/camera.dart';
import '../../../configs/application.dart';
import '../../../configs/config.dart';
import '../../../data/models/cmnd_model.dart';
import '../../../data/models/history.dart';
import '../../../data/providers/api_provider.dart';
import '../../../routes/app_pages.dart';
import '../../../utils/app_utils.dart';
import '../../../utils/convert_camera_image_to_png.dart';
import '../../../utils/file_until.dart';
import '../../../utils/logger.dart';

const String history = 'history-list';

class AppController extends GetxController {
  List<HistoryModel> historys = [];
  Uint8List? cardFront, cardBackside;
  Rx<CMNDModel> _cmndModel = CMNDModel().obs;
  Uint8List? portraitsImage, signature;
  CMNDModel get cmndModel => _cmndModel.value;
  final List<CameraImage> imageList = <CameraImage>[];
  RxBool isLoading = false.obs;
  @override
  void onInit() {
    final his = Application.preferences.getStringList(history);
    if (his != null) {
      historys = his.map((e) {
        return HistoryModel.fromMap(e);
      }).toList();
    }
    super.onInit();
  }

  Future<void> addHistory(HistoryModel historyModel) async {
    var faces = <String>[];
    for (var item in imageList) {
      var uint8list = Uint8List.fromList(convertImagetoPng(item)!);
      var path = await FileUtils.saveByteFile(uint8list);
      faces.add(path);
    }
    if (signature != null) {
      historyModel.signature = await FileUtils.saveByteFile(signature);
    }
    historyModel.faces = faces;
    historys.add(historyModel);
    final items = historys.map((e) => e.toJson()).toList();
    unawaited(Application.preferences.setStringList(history, items));
  }

  void setCmnnd(value) {
    _cmndModel.value = value;
  }

  void updateCard(Uint8List image, {isBackside = false}) {
    AppUtils.saveImage(image);
    if (isBackside) {
      cardBackside = image;
    } else {
      cardFront = image;
    }
  }

  void uploadIDCard() {
    isLoading.value = true;
    var cardFront = Get.find<AppController>().cardFront;
    var backside = Get.find<AppController>().cardBackside;
    if (cardFront == null || backside == null) {
      return UtilLogger.snackbar('Liveness đang xử lý vui lòng thử lại sau');
    }
    Get.offNamed(Routes.LIVENESS_DETECTION);
    ApiProvider.uploadID(cardFront, backside).then((response) {
      _cmndModel = CMNDModel.fromMap(response.data).obs;
      isLoading.value = false;
    }).onError((error, stackTrace) {
      isLoading.value = false;
      UtilLogger.snackbar(error.toString());
      Get.offAllNamed(Routes.CHOOSE_SCREEN);
    });
  }

  void updateInfo(HistoryModel historyModel) {
    final index = historys.indexWhere((e) => e.id == historyModel.id);
    if (index != -1) {
      historys[index] = historyModel;
      final items = historys.map((e) => e.toJson()).toList();
      Application.preferences.clear();
      Application.preferences.setStringList(history, items);
    }
  }

  @override
  void onClose() {}
}

==> 0.1.0.tar.gz: lib/app/modules/app/controllers/app_controller.dart <==
import 'package:get/get.dart';
import 'package:pedantic/pedantic.dart';
import 'dart:typed_data';

import 'package:camera/camera.dart';
import '../../../configs/application.dart';
import '../../../configs/config.dart';
import '../../../data/models/cmnd_model.dart';
import '../../../data/models/history.dart';
import '../../../data/providers/api_provider.dart';
import '../../../routes/app_pages.dart';
import '../../../utils/app_utils.dart';
import '../../../utils/convert_camera_image_to_png.dart';
import '../../../utils/file_until.dart';
import '../../../utils/logger.dart';

const String HISTORY = 'history-list';

class AppController extends GetxController {
  List<HistoryModel> historys = [];
  Uint8List? cardFront, cardBackside;
  Rx<CMNDModel> _cmndModel = CMNDModel().obs;
  Uint8List? portraitsImage, signature;
  CMNDModel get cmndModel => _cmndModel.value;
  final List<CameraImage> imageList = <CameraImage>[];
  RxBool isLoading = false.obs;
  @override
  void onInit() {
    final his = Application.preferences.getStringList(HISTORY);
    if (his != null) {
      historys = his.map((e) {
        return HistoryModel.fromMap(e);
      }).toList();
    }
    super.onInit();
  }

  Future<void> addHistory(HistoryModel historyModel) async {
    var faces = <String>[];
    for (var item in imageList) {
      var uint8list = Uint8List.fromList(convertImagetoPng(item)!);
      var path = await FileUtils.saveByteFile(uint8list);
      faces.add(path);
    }
    if (signature != null) {
      historyModel.signature = await FileUtils.saveByteFile(signature);
    }
    historyModel.faces = faces;
    historys.add(historyModel);
    final items = historys.map((e) => e.toJson()).toList();
    unawaited(Application.preferences.setStringList(HISTORY, items));
  }

  void setCmnnd(value) {
    _cmndModel.value = value;
  }

  void updateCard(Uint8List image, {isBackside = false}) {
    AppUtils.saveImage(image);
    if (isBackside) {
      cardBackside = image;
    } else {
      cardFront = image;
    }
  }

  void uploadIDCard() {
    isLoading.value = true;
    var cardFront = Get.find<AppController>().cardFront;
    var backside = Get.find<AppController>().cardBackside;
    if (cardFront == null || backside == null) {
      return UtilLogger.snackbar('Liveness đang xử lý vui lòng thử lại sau');
    }
    Get.offNamed(Routes.LIVENESS_DETECTION);
    ApiProvider.uploadID(cardFront, backside).then((response) {
      _cmndModel = CMNDModel.fromMap(response.data).obs;
      isLoading.value = false;
    }).onError((error, stackTrace) {
      isLoading.value = false;
      UtilLogger.snackbar(error.toString());
      Get.offAllNamed(Routes.CHOOSE_SCREEN);
    });
  }

  void updateInfo(HistoryModel historyModel) {
    final index = historys.indexWhere((e) => e.id == historyModel.id);
    if (index != -1) {
      historys[index] = historyModel;
      final items = historys.map((e) => e.toJson()).toList();
      Application.preferences.clear();
      Application.preferences.setStringList(HISTORY, items);
    }
  }

  @override
  void onClose() {}
}
